==> jaxrs-to-raml-raml-examples-2.0.0-sources.jar: org/raml/jaxrs/examples/ramlexamples/ConsumedValue.java <==
/*
 * Copyright 2013-2017 (c) MuleSoft, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 */
package org.raml.jaxrs.examples.ramlexamples;

import org.raml.jaxrs.common.Example;
import org.raml.jaxrs.common.RamlGenerator;
import org.raml.jaxrs.handlers.SimpleJaxbTypes;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.List;

/**
 * Created by Jean-Philippe Belanger on 3/26/17. Just potential zeroes and ones
 */
@XmlRootElement
@XmlAccessorType(XmlAccessType.PROPERTY)
@RamlGenerator(SimpleJaxbTypes.class)
public class ConsumedValue {

  @XmlElement
  @Example("foo")
  private String name;

  private int id;

  @Example("1")
  private SubType subType;

  @Example("['1','2','3']")
  private List<String> names;

  @Example("1")
  public int getId() {
    return id;
  }

  public SubType getSubType() {
    return subType;
  }

  public List<String> getNames() {
    return names;
  }
}

==> jaxrs-to-raml-raml-examples-3.0.0-sources.jar: org/raml/jaxrs/examples/ramlexamples/ConsumedValue.java <==
/*
 * Copyright 2013-2017 (c) MuleSoft, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific
 * language governing permissions and limitations under the License.
 */
package org.raml.jaxrs.examples.ramlexamples;

import org.raml.jaxrs.common.Example;
import org.raml.pojotoraml.plugins.RamlGenerator;
import org.raml.jaxrs.handlers.SimpleJaxbClassParser;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import java.util.List;

/**
 * Created by Jean-Philippe Belanger on 3/26/17. Just potential zeroes and ones
 */
@XmlRootElement
@XmlAccessorType(XmlAccessType.PROPERTY)
@RamlGenerator(parser = SimpleJaxbClassParser.class)
public class ConsumedValue {

  @XmlElement
  @Example("foo")
  private String name;

  private int id;

  @Example("1")
  private SubType subType;

  @Example("['1','2','3']")
  private List<String> names;

  @Example("1")
  public int getId() {
    return id;
  }

  public SubType getSubType() {
    return subType;
  }

  public List<String> getNames() {
    return names;
  }
}
